import { g as LogHandlerOptions, d as LogHandler, a as LogLevel } from './log-7206a2fe';

declare type BinInput = Uint8Array | ArrayBuffer | string | number[];
declare function stringToUInt8Array(text: string): Uint8Array;
declare function UInt8ArrayToString(bin: Uint8Array): string;
declare function toUint8Array(data: BinInput): Uint8Array;
declare function toHex(bin: BinInput): string;
declare function toBase64(bin: BinInput): string;
declare function toBase64Url(bin: BinInput): string;
/** Compare contents of binary arrays */
declare function equalBinary(a: ArrayBuffer | Uint8Array, b: ArrayBuffer | Uint8Array): boolean;

declare function randomUint8Array(length?: number): Uint8Array;
declare function digest(message: BinInput, algorithm?: AlgorithmIdentifier): Promise<ArrayBuffer>;
declare function deriveKeyPbkdf2(secret: BinInput, opt?: {
    iterations?: number;
    salt?: BinInput;
}): Promise<CryptoKey>;

declare function csv(data: any[], headerRow: string[]): string;

declare function useBase(alphaOrBase: string | number): {
    encode: (source: BinInput, padToLength?: number) => string;
    decode: (source: string, padToLength?: number) => Uint8Array;
};
declare const encodeBase16: (source: BinInput, padToLength?: number) => string;
declare const decodeBase16: (source: string, padToLength?: number) => Uint8Array;
declare const encodeBase32: (source: BinInput, padToLength?: number) => string;
declare const decodeBase32: (source: string, padToLength?: number) => Uint8Array;
declare const encodeBase58: (source: BinInput, padToLength?: number) => string;
declare const decodeBase58: (source: string, padToLength?: number) => Uint8Array;
declare const encodeBase62: (source: BinInput, padToLength?: number) => string;
declare const decodeBase62: (source: string, padToLength?: number) => Uint8Array;
declare const encodeBase64: (source: BinInput, padToLength?: number) => string;
declare const decodeBase64: (source: string, padToLength?: number) => Uint8Array;

declare const toCamelCase: (s: string) => string;
declare function toCapitalize(s: string): string;
declare function toCapitalizeWords(s: string): string;
declare function fromCamelCase(str: string, separator?: string): string;

declare function stringToBoolean(value?: string, defaultValue?: boolean): boolean;
declare function stringToInteger(value?: string, defaultValue?: number): number;
declare function stringToFloat(value?: string, defaultValue?: number): number;
declare function valueToBoolean(value?: any, defaultValue?: boolean): boolean;
declare function valueToInteger(value?: any, defaultValue?: number): number;
declare function valueToFloat(value?: any, defaultValue?: number): number;
declare function valueToString(value?: any, defaultValue?: string): string;
declare const toFloat: typeof valueToFloat;
declare const toInt: typeof valueToInteger;
declare const toString: typeof valueToString;
declare const toBool: typeof valueToBoolean;
declare type RenderMessagesOptions = {
    trace?: boolean;
    pretty?: boolean;
};
declare function formatMessages(messages: any[], opt?: RenderMessagesOptions): any[];
declare function renderMessages(messages: any[], opt?: RenderMessagesOptions): string;
declare function fixBrokenUth8String(brokenString: string): string;

declare type CurrencyInput = number | string | Currency;
declare type CurrencyFormat = (currency?: Currency, opts?: CurrencyOptions) => string;
interface CurrencyOptions {
    symbol?: string;
    separator?: string;
    decimal?: string;
    errorOnInvalid?: boolean;
    precision?: number;
    increment?: number;
    useVedic?: boolean;
    pattern?: string;
    negativePattern?: string;
    format?: CurrencyFormat;
    fromCents?: boolean;
    groups?: RegExp;
}
declare function currency(value: CurrencyInput, opts?: CurrencyOptions): Currency;
/**
 * Immuteable currency representation
 */
declare class Currency {
    readonly intValue: number;
    readonly value: number;
    private readonly _settings;
    private readonly _precision;
    constructor(value: CurrencyInput, opts?: CurrencyOptions);
    add(number: CurrencyInput): Currency;
    subtract(number: CurrencyInput): Currency;
    multiply(number: number): Currency;
    divide(number: CurrencyInput): Currency;
    distribute(count: number): number[];
    dollars(): number;
    cents(): number;
    format(options: CurrencyOptions | Function): any;
    toString(): string;
    toJSON(): number;
    static zero: Currency;
    static one: Currency;
    static sum(...array: (CurrencyInput | CurrencyInput[])[]): Currency;
    static avg(...array: (CurrencyInput | CurrencyInput[])[]): Currency;
}
declare type RoundingMode = (value: number) => number;
declare const isHalf: (value: number) => boolean;
declare const isEven: (value: number) => boolean;
declare const roundUp: RoundingMode;
declare const roundDown: RoundingMode;
declare const roundHalfUp: RoundingMode;
/**
 * Round a number with half values to nearest odd integer.
 */
declare const roundHalfOdd: RoundingMode;
/**
 * Round a number with half values to nearest integer farthest from zero.
 */
declare const roundHalfAwayFromZero: RoundingMode;
/**
 * Round a number with half values down.
 */
declare const roundHalfDown: RoundingMode;
/**
 * Round a number with half values to nearest even integer.
 * https://wiki.c2.com/?BankersRounding
 */
declare const roundHalfEven: RoundingMode;
/**
 * Round a number with half values to nearest integer closest to zero.
 */
declare const roundHalfTowardsZero: RoundingMode;

declare const DAY_MS: number;
declare type DayInput = number | string | Date | Day;
declare class Day {
    days: number;
    constructor(days?: DayInput);
    static fromNumber(n: number): Day;
    static fromString(dateString: string): Day | undefined;
    static fromDate(date: Date, gmt?: boolean): Day;
    static fromDateGMT(date: Date): Day;
    static from(value: DayInput, gmt?: boolean): Day | undefined;
    toNumber(): number;
    /** Just for future extensions */
    toJson(): number;
    toString(sep?: string): string;
    toDate(gmt?: boolean): Date;
    toDateGMT(): Date;
    dayOffset(offset: number): Day;
    daysUntil(otherDay: DayInput): number;
    yesterday(): Day;
    tomorrow(): Day;
}
declare function forEachDay(from: DayInput, to: DayInput, handler: (date: Day) => Promise<void> | void): Promise<void>;
declare function today(): Day;

declare const escapeHTML: (s: string) => string;
declare const unescapeHTML: (s: string) => string;

declare type EntryProcessor = (key: string, value: any) => any;
/**
 * Similar to JSON.stringify but can handle circular references
 */
declare function jsonStringify(obj: any, replacer?: EntryProcessor | null, spaces?: string | number | null, cycleReplacer?: EntryProcessor): string;

declare function parseOrderby(value?: string): {
    field: string;
    orderby: string;
    asc: boolean;
    desc: boolean;
};
declare function composeOrderby(field: string, asc?: boolean): string;
declare function cmp(a: any, b: any, asc?: boolean): number;
declare function sortedOrderby<T>(values: T[], ...orderby: string[]): T[];

declare function toValidFilename(string: string): string;

declare function escapeRegExp(value: RegExp | string): string;

interface SortableItem {
    sort_weight: number;
}
declare function startSortWeight(items: SortableItem[]): number;
declare function endSortWeight(items: SortableItem[]): number;
declare function moveSortWeight(newIndex: number, oldIndex: number, items: SortableItem[]): number;
declare function sortedItems<T extends SortableItem>(items: T[]): T[];

declare function linkifyPlainText(text: string): string;
declare function toHumanReadableUrl(url: string): string;
declare function encodeQuery(data: Record<string, any>): string;
declare function parseQuery(queryString: string): any;

declare function size(obj: any): any;
declare function last<T>(array?: T[]): T | undefined;
declare function empty(value: any): boolean;
declare function cloneObject<T>(obj: T): T;

declare type Json = string | number | boolean | null | {
    [property: string]: Json;
} | Json[];
interface ObjectStorage<T = any> {
    setItem(key: string, value: T): void;
    getItem(key: string): T | undefined;
    removeItem(key: string): void;
    clear(): void;
    allKeys(): string[];
}
declare type NestedArray<T> = T | Array<NestedArray<T>>;

declare function arrayUnique<T>(x: T[]): T[];
declare function arrayMinus<T>(x: T[], y: T[]): T[];
declare function arrayUnion<T>(...a: T[][]): T[];
/** `[1,[2,3]]` becomes `[1,2,3]` */
declare function arrayFlatten<T>(...list: NestedArray<T>[]): T[];
declare function arrayIntersection<T>(x: T[], y: T[]): T[];
declare function arraySymmetricDifference<T>(x: T[], y: T[]): T[];
declare function arrayRemoveElement<T>(arr: T[], el: T): T[];
/** Only have it once in the set */
declare function arraySetElement<T>(arr: T[], el: T): T[];
declare function arrayFilterInPlace<T>(array: T[], fn: (el: T) => boolean): T[];
declare function arrayToggleInPlace<T>(array: T[], el: T): T[];
declare function arrayEmptyInPlace<T>(array: T[]): T[];
declare function arraySorted<T>(arr: Iterable<T> | ArrayLike<T>, cond?: ((a: T, b: T) => number) | undefined): T[];
declare function arraySortedNumbers(arr: number[]): number[];
declare function arrayIsEqual<T>(array1: T[], array2: T[]): boolean;
declare function arrayShuffleInPlace<T>(array: T[]): T[];
declare function arrayShuffle<T>(array: T[]): T[];
/** Randomly shuffle the order of the array's elements. Force to have a different order if array has more than one element. */
declare function arrayShuffleForce<T>(array: T[]): T[];
declare function arrayRandomElement<T>(array: T[]): T;
declare function arrayMax<T>(...array: NestedArray<T>[]): T;
declare function arrayMin<T>(...array: NestedArray<T>[]): T;

declare const isObject: (obj: any) => any;
declare const isPrimitive: (obj: any) => boolean;
declare function deepEqual(a: any, b: any, hash?: WeakSet<object>): boolean;
declare function deepMerge(target: any, ...sources: any[]): any;

declare type DisposerFunction = () => void | Promise<void>;
declare type Disposer = DisposerFunction | {
    dispose?: Function | Promise<unknown>;
    cleanup?: Function | Promise<unknown>;
};
interface Disposable {
    dispose(): void | Promise<void>;
}
/** Different kinds of implementations have grown, this should unify them  */
declare function callDisposer(disposable: Disposer): Promise<void>;
declare function useDisposer(): (() => Promise<void>) & {
    track: (obj: Disposer) => DisposerFunction;
    untrack: (disposable: Disposer) => Promise<void>;
    dispose: () => Promise<void>;
    getSize(): number;
};
declare function useTimeout(fn: Function, timeout?: number): DisposerFunction;
declare function useInterval(fn: Function, interval: number): DisposerFunction;
declare function useEventListener(emitter: any, eventName: string, fn: (ev?: any) => void, ...args: any[]): DisposerFunction;

declare global {
    interface ZeedGlobalContext {
    }
}
declare function getGlobalContext(): ZeedGlobalContext;

declare function isLocalHost(hostname?: string): boolean;

/**
 * Very basic logger. Please take a look at the browser and node
 * optimized loggers. This one is just the absolute fallback option.
 *
 * @param level Log level
 * @returns Logger
 */
declare function LoggerConsoleHandler(opt?: LogHandlerOptions): LogHandler;

interface NamespaceFilter {
    (name: string): boolean;
    accept: RegExp[];
    reject: RegExp[];
    filter: string;
}
declare function getNamespaceFilterString(defaultNamespaceFilter: any): string;
/**
 * Filter as described here https://github.com/visionmedia/debug#wildcards
 *
 * @param filter Namespace filter
 * @returns Function to check if filter applies
 */
declare function useNamespaceFilter(filter?: string): NamespaceFilter;
declare function useLevelFilter(filter?: string | number): (level: LogLevel) => boolean;

declare type EmitterHandler = (...objs: any[]) => void;
declare type EmitterAllHandler<T = string> = (key: T, ...objs: any[]) => void;
declare type ListenerSignature<L> = {
    [E in keyof L]: (...args: any[]) => any;
};
declare type DefaultListener = {
    [k: string]: (...args: any[]) => any;
};
declare class Emitter<L extends ListenerSignature<L> = DefaultListener> implements Disposable {
    subscribers: any;
    subscribersOnAny: any[];
    call: L;
    emit<U extends keyof L>(event: U, ...args: Parameters<L[U]>): Promise<boolean>;
    onAny(fn: EmitterHandler): void;
    on<U extends keyof L>(event: U, listener: L[U]): DisposerFunction;
    onCall(handlers: Partial<L>): void;
    once<U extends keyof L>(event: U, listener: L[U]): DisposerFunction;
    off<U extends keyof L>(event: U, listener: L[U]): this;
    removeAllListeners(event?: keyof L): this;
    dispose(): void;
}
declare global {
    interface ZeedGlobalContext {
        emitter?: Emitter;
    }
    interface ZeedGlobalEmitter {
    }
}
/** Global emitter that will listen even across modules */
declare function getGlobalEmitter(): Emitter<ZeedGlobalEmitter>;
declare const messages: Emitter<DefaultListener>;
declare function lazyListener(emitter: any, listenerKey?: string): (key?: string, skipUnmatched?: boolean) => Promise<any>;

/** See http://developer.mozilla.org/en-US/docs/Web/API/MessageEvent */
interface ChannelMessageEvent {
    data: any;
    origin?: string;
    lastEventId?: string;
}
/**
 * Inspired by
 * http://developer.mozilla.org/en-US/docs/Web/API/BroadcastChannel
 * https://deno.com/deploy/docs/runtime-broadcast-channel
 * */
declare abstract class Channel extends Emitter<{
    message(event: ChannelMessageEvent): void;
    messageerror(event: ChannelMessageEvent): void;
    connect(): void;
    disconnect(): void;
    close(): void;
}> {
    id: string;
    abstract isConnected?: boolean;
    abstract postMessage(data: any): void;
    close(): void;
}
/** Very basic channel demonstrating local communication */
declare class LocalChannel extends Channel {
    isConnected: boolean;
    other?: LocalChannel;
    postMessage(data: any): void;
}
declare function fakeWorkerPair(): [LocalChannel, LocalChannel];

interface Encoder {
    encode(data: any): Promise<Uint8Array>;
    decode(data: Uint8Array): Promise<any>;
}
declare class JsonEncoder implements Encoder {
    encode(data: any): Promise<Uint8Array>;
    decode(data: Uint8Array): Promise<any>;
}

declare type MessageAction = {
    name: string;
    id: string;
    args?: Json[];
};
declare type MessageResult = {
    id: string;
    result?: Json;
    error?: {
        stack?: string;
        name: string;
        message: string;
    };
};
declare type Message = MessageAction | MessageResult;
declare type MessagesOptions = {
    timeout?: number;
};
declare type MessagesDefaultMethods<L> = {
    dispose(): void;
    connect?(channel: Channel): void;
    options(opt: MessagesOptions): L;
};
declare type MessagesMethods<L> = L & MessagesDefaultMethods<L>;
declare type MessageHub = {
    dispose(): void;
    connect: (newChannel: Channel) => void;
    listen<L extends object>(newHandlers: L): void;
    send<L extends object>(): MessagesMethods<L>;
};
declare const createPromiseProxy: <P extends object>(fn: (name: string, args: any[], opt: any) => Promise<unknown>, opt: MessagesOptions, predefinedMethods?: any) => P;
declare function useMessageHub(opt?: {
    name?: string;
    channel?: Channel;
    encoder?: Encoder;
    retryAfter?: number;
    ignoreUnhandled?: boolean;
    debug?: boolean;
}): MessageHub;

interface PubSubConfig {
    channel: Channel;
    encoder?: Encoder;
    name?: string;
    debug?: boolean;
}
declare class PubSub<L extends ListenerSignature<L> = DefaultListener> extends Emitter<L> {
    name: string;
    channel: Channel;
    encoder: Encoder;
    log: any;
    debug: boolean;
    get shortId(): string;
    constructor(opt: PubSubConfig);
    private emitSuper;
    emit<U extends keyof L>(event: U, ...args: Parameters<L[U]>): Promise<boolean>;
    publish: <U extends keyof L>(event: U, ...args: Parameters<L[U]>) => Promise<boolean>;
    subscribe: <U extends keyof L>(event: U, listener: L[U]) => DisposerFunction;
}
declare function usePubSub<L extends ListenerSignature<L> = DefaultListener>(opt: PubSubConfig): PubSub<L>;

declare type Mutex = (fn: () => void, elseFn?: () => void) => boolean;
declare function createMutex(): Mutex;

declare function fetchBasic(url: string, fetchOptions?: any, fetchFn?: (input: RequestInfo, init?: RequestInit) => Promise<Response>): Promise<Response | undefined>;
declare function fetchJson(url: string, opts?: any, fetchFn?: (input: RequestInfo, init?: RequestInit) => Promise<Response>): Promise<Json | undefined>;
declare function fetchOptionsFormURLEncoded(data: Object, method?: "GET" | "POST"): {
    headers: {
        "Content-Type": string;
    };
    body: string;
    cache: string;
    redirect: string;
    method: "GET" | "POST";
};
declare function fetchOptionsJson(data: Object, method?: "GET" | "POST"): {
    headers: {
        "Content-Type": string;
        Accept: string;
    };
    body: string;
    cache: string;
    redirect: string;
    method: "GET" | "POST";
};
declare function fetchText(url: string, opts?: any, fetchFn?: (input: RequestInfo, init?: RequestInit) => Promise<Response>): Promise<string | undefined>;

declare function getWindow(): any | undefined;
declare function getNavigator(): any | undefined;
declare function getGlobal(): any;
declare function detect(info?: {
    ios: boolean;
    macos: boolean;
    windows: boolean;
    beaker: boolean;
    electron: boolean;
    wkwebview: boolean;
    pwa: boolean;
    pwaInstalled: boolean;
    browser: boolean;
    node: boolean;
    worker: boolean;
    jest: boolean;
    macosNative: boolean;
    iosNative: boolean;
    appleNative: boolean;
    touch: boolean;
}): {
    ios: boolean;
    macos: boolean;
    windows: boolean;
    beaker: boolean;
    electron: boolean;
    wkwebview: boolean;
    pwa: boolean;
    pwaInstalled: boolean;
    browser: boolean;
    node: boolean;
    worker: boolean;
    jest: boolean;
    macosNative: boolean;
    iosNative: boolean;
    appleNative: boolean;
    touch: boolean;
};
declare const isBrowser: () => boolean;
declare const platform: {
    ios: boolean;
    macos: boolean;
    windows: boolean;
    beaker: boolean;
    electron: boolean;
    wkwebview: boolean;
    pwa: boolean;
    pwaInstalled: boolean;
    browser: boolean;
    node: boolean;
    worker: boolean;
    jest: boolean;
    macosNative: boolean;
    iosNative: boolean;
    appleNative: boolean;
    touch: boolean;
};
/**
 * Before closing the tab/window or quitting the node process
 * allow to do something important first
 */
declare function useExitHandler(handler: () => void): void;

/** Sleep for `milliSeconds`. Example 1s: `await sleep(1000)` */
declare function sleep(milliSeconds: number): Promise<void>;
declare function immediate(): Promise<void>;
declare const timeoutReached: unique symbol;
declare function timeout<T>(promise: Promise<T>, milliSeconds: number, timeoutValue?: symbol): Promise<T | typeof timeoutValue>;
declare const timoutError: Error;
declare function isTimeout(value: any): boolean;
declare function tryTimeout<T>(promise: Promise<T>, milliSeconds: number): Promise<T | undefined>;
/** Wait for `event` on `obj` to emit. Resolve with result or reject on `timeout` */
declare function waitOn(obj: any, event: string, timeoutMS?: number): Promise<any>;
declare function isPromise<T>(value: Promise<T> | T): value is Promise<T>;
/** This is exactly what Prose.resolve(x) is supposed to be: return a Promise no matter what type x is */
declare function promisify<T>(value: Promise<T> | T): Promise<T>;

declare type QueueTask<T = any> = () => Promise<T>;
/** Guarentee serial execution of tasks. Able to wait, pause, resume and cancel all. */
declare class SerialQueue {
    private queue;
    private isPaused;
    private waitToFinish;
    private currentTask?;
    private log;
    name: string;
    constructor(opt?: {
        name?: string;
        logLevel?: LogLevel;
    });
    private performNext;
    /** Enqueue task to be executed when all other tasks are done. Except `immediate = true`. */
    enqueue<T>(task: QueueTask<T>, opt?: {
        immediate?: boolean;
        name?: string;
    }): Promise<T>;
    /** If a task is already performing, execute immediately. Otherwise enqueue as usual. */
    enqueueReentrant<T>(task: QueueTask<T>, opt?: {
        name?: string;
    }): Promise<T>;
    /** Remove all tasks from queue that are not yet executing. */
    cancelAll(unblock?: boolean): Promise<void>;
    /** Pause execution after current task is finished. */
    pause(): Promise<void>;
    /** Resume paused queue. */
    resume(): void;
    /** Wait for all tasks to finish */
    wait(): Promise<unknown>;
}

interface MemStorageOptions {
    objectFromString?: (data: string) => any;
    objectToString?: (data: any) => string;
}
declare class MemStorage<T = Json> implements ObjectStorage<T> {
    private store;
    constructor(opt?: MemStorageOptions);
    setItem(key: string, value: T): void;
    getItem(key: string): T | undefined;
    removeItem(key: string): void;
    clear(): void;
    allKeys(): string[];
}

interface DebounceOptions {
    delay?: number;
    noTrailing?: boolean;
    debounceMode?: boolean;
}
declare type DebounceFunction = Function & {
    cancel: () => void;
    dispose: () => void;
};
declare function throttle(callback: Function, opt?: DebounceOptions): DebounceFunction;
declare function debounce(callback: Function, opt?: DebounceOptions): DebounceFunction;
declare function throttleAnimationFrame(callback: Function): DebounceFunction;

/**
 * @returns Timestamp in miliseconds
 */
declare const getTimestamp: () => number;
declare function formatMilliseconds(ms: number): string;
declare function parseDate(...dateCandidates: (string | Date)[]): Date | undefined;

declare function uuid(): string;
declare function uuidB32(): string;
declare function uname(name?: string): string;
declare function qid(): string;
declare const uuidv4: () => string;
declare function suidBytes(): Uint8Array;
declare function suid(): string;
declare function suidDate(id: string): Date;
declare function suidBytesDate(id: Uint8Array): Date;

export { roundHalfDown as $, stringToInteger as A, BinInput as B, stringToFloat as C, valueToBoolean as D, valueToInteger as E, valueToFloat as F, valueToString as G, toFloat as H, toInt as I, toString as J, toBool as K, formatMessages as L, renderMessages as M, fixBrokenUth8String as N, CurrencyInput as O, currency as P, Currency as Q, RenderMessagesOptions as R, RoundingMode as S, isHalf as T, UInt8ArrayToString as U, isEven as V, roundUp as W, roundDown as X, roundHalfUp as Y, roundHalfOdd as Z, roundHalfAwayFromZero as _, deriveKeyPbkdf2 as a, LoggerConsoleHandler as a$, roundHalfEven as a0, roundHalfTowardsZero as a1, DAY_MS as a2, DayInput as a3, Day as a4, forEachDay as a5, today as a6, escapeHTML as a7, unescapeHTML as a8, jsonStringify as a9, arraySetElement as aA, arrayFilterInPlace as aB, arrayToggleInPlace as aC, arrayEmptyInPlace as aD, arraySorted as aE, arraySortedNumbers as aF, arrayIsEqual as aG, arrayShuffleInPlace as aH, arrayShuffle as aI, arrayShuffleForce as aJ, arrayRandomElement as aK, arrayMax as aL, arrayMin as aM, isObject as aN, isPrimitive as aO, deepEqual as aP, deepMerge as aQ, DisposerFunction as aR, Disposer as aS, Disposable as aT, callDisposer as aU, useDisposer as aV, useTimeout as aW, useInterval as aX, useEventListener as aY, getGlobalContext as aZ, isLocalHost as a_, parseOrderby as aa, composeOrderby as ab, cmp as ac, sortedOrderby as ad, toValidFilename as ae, escapeRegExp as af, SortableItem as ag, startSortWeight as ah, endSortWeight as ai, moveSortWeight as aj, sortedItems as ak, linkifyPlainText as al, toHumanReadableUrl as am, encodeQuery as an, parseQuery as ao, size as ap, last as aq, empty as ar, cloneObject as as, arrayUnique as at, arrayMinus as au, arrayUnion as av, arrayFlatten as aw, arrayIntersection as ax, arraySymmetricDifference as ay, arrayRemoveElement as az, decodeBase16 as b, NestedArray as b$, getNamespaceFilterString as b0, useNamespaceFilter as b1, useLevelFilter as b2, ChannelMessageEvent as b3, Channel as b4, LocalChannel as b5, fakeWorkerPair as b6, EmitterHandler as b7, EmitterAllHandler as b8, ListenerSignature as b9, getNavigator as bA, getGlobal as bB, detect as bC, isBrowser as bD, platform as bE, useExitHandler as bF, sleep as bG, immediate as bH, timeoutReached as bI, timeout as bJ, timoutError as bK, isTimeout as bL, tryTimeout as bM, waitOn as bN, isPromise as bO, promisify as bP, SerialQueue as bQ, MemStorageOptions as bR, MemStorage as bS, throttle as bT, debounce as bU, throttleAnimationFrame as bV, getTimestamp as bW, formatMilliseconds as bX, parseDate as bY, Json as bZ, ObjectStorage as b_, DefaultListener as ba, Emitter as bb, getGlobalEmitter as bc, messages as bd, lazyListener as be, Encoder as bf, JsonEncoder as bg, MessageAction as bh, MessageResult as bi, Message as bj, MessagesOptions as bk, MessagesDefaultMethods as bl, MessagesMethods as bm, MessageHub as bn, createPromiseProxy as bo, useMessageHub as bp, PubSub as bq, usePubSub as br, Mutex as bs, createMutex as bt, fetchBasic as bu, fetchJson as bv, fetchOptionsFormURLEncoded as bw, fetchOptionsJson as bx, fetchText as by, getWindow as bz, csv as c, uuid as c0, uuidB32 as c1, uname as c2, qid as c3, uuidv4 as c4, suidBytes as c5, suid as c6, suidDate as c7, suidBytesDate as c8, digest as d, encodeBase16 as e, encodeBase32 as f, decodeBase32 as g, encodeBase58 as h, decodeBase58 as i, encodeBase62 as j, decodeBase62 as k, encodeBase64 as l, decodeBase64 as m, toHex as n, toBase64 as o, toBase64Url as p, equalBinary as q, randomUint8Array as r, stringToUInt8Array as s, toUint8Array as t, useBase as u, toCamelCase as v, toCapitalize as w, toCapitalizeWords as x, fromCamelCase as y, stringToBoolean as z };
